/*
   sd_cy7c63743.h for SmartDongle API version 3.2

   The particulars of the Cypress CY7C63743 USB peripheral controller
   and related configuration parameters.


   www.smartdongle.com

   MicroWorks, Inc.
   2808 North Cole Road
   Boise, ID 83704
*/

#ifndef _DEFINED_406D2031_F187_4478_B6AE_BF44857A530A
#define _DEFINED_406D2031_F187_4478_B6AE_BF44857A530A

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*
   Various timeouts (in mSec).
*/
#define QTSPAGEWAIT  2000  /* Max time period to wait for an EEPROM page */
#define QTSSTATEWAIT 2500  /* Max time period to wait for a state change */
#define QTSTWCWAIT   2000  /* Max time period to wait for Time Write Cycle. */
#define QTSBUSYWAIT  5000  /* Max time period to wait for task_loop */

#define QTSPACKETSIZE 8   /* Each USB low speed packet is 8 bytes */

#define QTSMAXBUFFERLENGTH 255

/*
 Page flag bits: IOCTL_QTSDONGLE_GET_PAGE_FLAGS
*/
#define QTSRDPAGEVALID    0x01
#define QTSWRPAGEVALID    0x02

/* EEPROM read page errors */
#define QTSRDADDRESSRANGE 0x04
#define QTSRDDENY         0x08
#define QTSRDEEPROMERROR  0x10  /* SPI EPROM read timeout */

/* EEPROM write page errors */
#define QTSWRADDRESSRANGE 0x20
#define QTSWRDENY         0x40
#define QTSWREEPROMERROR  0x80 /* SPI EPROM write timeout */

/*
   Users not given function to access IOCTL_QTSDONGLE_GET_EEPROM_ERROR_FLAG
*/

/* EEPROM SPI access timeout */
#define QTSRDTIMEOUT      0x01

/* EEPROM SPI access timeout and data miscompare */
#define QTSWRTIMEOUT      0x10
#define QTSWRDATA         0x20

/*
  The Time Write Cycle status
  The status of the Time Write Cycle register.
  If the register indicates that a write cycle is
  active, an EEPROM read or write is denied.
  : IOCTL_QTSDONGLE_GET_TWC_FLAG
*/
#define QTSTWCACTIVE      0xFF
#define QTSTWCINACTIVE    0x00

/*
  Task loop activity flag
  IOCTL_QTSDONGLE_GET_BUSY_FLAG
*/
#define QTSREADY          0x00
#define QTSBUSY           0xFF

/*
  The 8 bit ouput port address, the CY7C63221 has P0.0 - P0.8, and P2.0, P2.1
  (XTALIN, XTALOUT disabled)
*/
#define QTSPORT0  0x00
#define QTSPORT1  0x01
#define QTSPORT2  0x02

/*
  The 8 bit output port LED drive is active low, using lines 0 and 1
*/
#define QTSLEDPORT  QTSPORT0
#define QTSLEDOFF 0xFF
#define QTSGREEN  0xFE
#define QTSRED    0xFD

/*
  Security states
*/
#define QTSDISABLED 0x00
#define QTSENABLED  0x01

/*
  Key states for host/dongle authentication handshake
*/
#define QTSINITIAL  0x00
#define QTSREPLY    0x01

/*
  Bitmap of SmartDongle status byte.
*/
#define QTSKEYSTATEBIT   0x80
   #define QTSKEYINITIAL 0x00
   #define QTSKEYREPLY   0x80

#define QTSTWCSTATEBIT   0x04
   #define QTSTWCBUSY    0x04
   #define QTSTWCDONE    0x00

#define QTSBUSYSTATEBIT  0x20
   #define QTSISBUSY     0x20
   #define QTSNOTBUSY    0x00

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

#endif /* _DEFINED_406D2031_F187_4478_B6AE_BF44857A530A */
